@@ -24,6 +24,7 @@ class Contract(object):
         self.bytecode = ''
         self.opcode = []
         self.function_signatures = []
+        self.function_definitions = []
 
     def get_bytecode(self):
         return self.bytecode
@@ -34,6 +35,9 @@ class Contract(object):
     def get_function_signature_list(self):
         return self.function_signatures
 
+    def get_function_definition_list(self):
+        return self.function_definitions
+
     def get_opcode_occurrence(self, collapse=0):
         opcode_list = [item[2] for item in self.opcode]
         return opcode_occurrence(opcode_list, collapse)
