@@ -312,6 +312,9 @@ def get_function_definitions_list(function_signatures):
     '''
 
     definition_list = []
-    for signature in function_signatures:
-        definition_list.append(signature_to_function(signature))
+    try:
+        for signature in function_signatures:
+            definition_list.append(signature_to_function(signature))
+    except:
+        print('Function Signature Database not Avaliable.')
     return definition_list
\ No newline at end of file
